@@ -6,11 +6,13 @@ use Illuminate\Support\Facades\Crypt;
 use Illuminate\Support\Facades\Log;
 use LdapRecord\Auth\Guard as GuardBase;
 
+use App\Classes\LDAP\Attribute\Password;
+
 class Guard extends GuardBase
 {
 	public function attempt(string $username, string $password, bool $stayBound = false): bool
 	{
-		Log::info(sprintf('Attempting login for [%s] with password [%s]',$username,($password ? str_repeat('*',16) : str_repeat('?',16))));
+		Log::info(sprintf('ALG:Attempting login for [%s] with password [%s]',$username,($password ? Password::obfuscate : str_repeat('?',16))));
 
 		if ($result = parent::attempt($username,$password,$stayBound)) {
 			// Store user details so we can swap in auth details in SwapinAuthUser
