@@ -1,15 +1,7 @@
-@use(App\Ldap\Entry)
-
 @extends('layouts.dn')
 
 @section('page_title')
-	@include('fragment.dn.header',[
-		'o'=>($o ?? $o=$server->fetch($dn)),
-		'langtags'=>($langtags=$o->getLangTags()
-			->flatMap(fn($item)=>$item->values())
-			->unique()
-			->sort())
-	])
+	@include('fragment.dn.header')
 @endsection
 
 @section('page_actions')
@@ -17,30 +9,31 @@
 		<div class="col">
 			<div class="action-buttons float-end">
 				<ul class="nav">
-					@if(isset($page_actions) && $page_actions->get('create'))
+					@if($page_actions->get('create'))
 						<li>
 							<button class="btn btn-outline-dark p-1 m-1" id="entry-create" data-bs-toggle="tooltip" data-bs-placement="bottom" title="@lang('Create Child Entry')"><i class="fas fa-fw fa-diagram-project fs-5"></i></button>
 						</li>
 					@endif
-					@if(isset($page_actions) && $page_actions->get('export'))
+					@if($page_actions->get('export'))
 						<li>
 							<span id="entry-export" data-bs-toggle="modal" data-bs-target="#page-modal">
 								<button class="btn btn-outline-dark p-1 m-1" data-bs-toggle="tooltip" data-bs-placement="bottom" title="@lang('Export')"><i class="fas fa-fw fa-download fs-5"></i></button>
 							</span>
 						</li>
 					@endif
-					@if(isset($page_actions) && $page_actions->get('copy'))
+					@if($page_actions->get('copy'))
 						<li>
-							<button class="btn btn-outline-dark p-1 m-1" id="entry-copy-move" data-bs-toggle="tooltip" data-bs-placement="bottom" title="@lang('Copy/Move')" disabled><i class="fas fa-fw fa-copy fs-5"></i></button>
+							<span id="entry-copy-move" data-bs-toggle="modal" data-bs-target="#page-modal">
+								<button class="btn btn-outline-dark p-1 m-1" data-bs-toggle="tooltip" data-bs-placement="bottom" title="@lang('Copy/Move')"><i class="fas fa-fw fa-copy fs-5"></i></button>
+							</span>
 						</li>
 					@endif
-					@if(isset($page_actions) && $page_actions->get('edit'))
+					@if($page_actions->get('edit'))
 						<li>
 							<button class="btn btn-outline-dark p-1 m-1" id="entry-edit" data-bs-toggle="tooltip" data-bs-placement="bottom" title="@lang('Edit Entry')"><i class="fas fa-fw fa-edit fs-5"></i></button>
 						</li>
 					@endif
-					<!-- @todo Dont offer the delete button for an entry with children -->
-					@if(isset($page_actions) && $page_actions->get('delete'))
+					@if($page_actions->get('delete'))
 						<li>
 							<span id="entry-delete" data-bs-toggle="modal" data-bs-target="#page-modal">
 								<button class="btn btn-outline-danger p-1 m-1" data-bs-custom-class="custom-tooltip-danger" data-bs-toggle="tooltip" data-bs-placement="bottom" title="@lang('Delete Entry')"><i class="fas fa-fw fa-trash-can fs-5"></i></button>
@@ -58,15 +51,12 @@
 		<div class="alert alert-danger p-2">
 			This entry has [<strong>{!! $x->flatten()->join('</strong>, <strong>') !!}</strong>] tags used by [<strong>{!! $x->keys()->join('</strong>, <strong>') !!}</strong>] that cant be managed by PLA. You can though manage those tags with an LDIF import.
 		</div>
-	@elseif(($x=$o->getLangMultiTags())->count())
-		<div class="alert alert-danger p-2">
-			This entry has multi-language tags used by [<strong>{!! $x->keys()->join('</strong>, <strong>') !!}</strong>] that cant be managed by PLA. You can though manage those lang tags with an LDIF import.
-		</div>
 	@endif
 
+	<x-success/>
+	<x-updated :updated="$updated"/>
 	<x-note/>
 	<x-error/>
-	<x-updated/>
 	<x-failed/>
 @endsection
 
@@ -82,84 +72,61 @@
 				<div class="tab-content">
 					<!-- All Attributes -->
 					<div class="tab-pane active" id="attributes" role="tabpanel">
-						<form id="dn-edit" method="POST" class="needs-validation" action="{{ url('entry/update/pending') }}" novalidate readonly>
-							@csrf
-
-							<input type="hidden" name="dn" value="">
-							<div class="card-header border-bottom-0">
-								<div class="btn-actions-pane-right">
-									<div role="group" class="btn-group-sm nav btn-group">
-										@php
-											$langtags->prepend(Entry::TAG_NOTAG);
-											if (isset($page_actions) && $page_actions->get('edit'))
-												$langtags->push('+');
-										@endphp
-
-										@foreach($langtags as $tag)
-											<a data-bs-toggle="tab" href="#tab-lang-{{ $tag ?: '_default' }}" @class(['btn','btn-outline-light','border-dark-subtle','active'=>!$loop->index])>
-												@switch($tag)
-													@case(Entry::TAG_NOTAG)
-														<i class="fas fa-fw fa-border-none" data-bs-toggle="tooltip" data-bs-custom-class="custom-tooltip" title="@lang('No Lang Tag')"></i>
-														@break
-
-													@case('+')
-														<!-- @todo To implement -->
-														<i class="fas fa-fw fa-plus text-dark" data-bs-toggle="tooltip" data-bs-custom-class="custom-tooltip" title="@lang('Add Lang Tag')"></i>
-														@break
-
-													@default
-														<span class="f16" data-bs-toggle="tooltip" data-bs-custom-class="custom-tooltip" title="{{ strtoupper($tag) }}"><i class="flag {{ $tag }}"></i></span>
-												@endswitch
-											</a>
+						<div class="row pt-3">
+							<div class="col-12">
+								<div class="d-flex justify-content-center">
+									<div class="btn-group btn-group-sm nav pb-3" role="group">
+										<!-- If we have templates that cover this entry -->
+										@foreach($o->templates as $template)
+											<span data-bs-toggle="tab" href="#template-{{ $template->name }}" @class(['btn','btn-outline-focus','active'=>$loop->index === 0])><i class="fa fa-fw pe-2 {{ $template->icon }}"></i> {{ $template->title }}</span>
 										@endforeach
+
+										@if($o->templates->count())
+											<span data-bs-toggle="tab" href="#template-default" @class(['btn','btn-outline-focus','p-1','active'=>(! $o->templates->count())])><i class="fa fa-fw fa-list pe-2"></i> {{ __('LDAP Entry') }}</span>
+										@endif
 									</div>
 								</div>
-							</div>
 
-							<div class="card-body">
 								<div class="tab-content">
-									@php($up=(session()->pull('updated') ?: collect()))
-									@foreach($langtags as $tag)
-										<div class="tab-pane @if(! $loop->index) active @endif" id="tab-lang-{{ $tag ?: '_default' }}" role="tabpanel">
-											@switch($tag)
-												@case(Entry::TAG_NOTAG)
-													@foreach ($o->getVisibleAttributes($tag) as $ao)
-														<x-attribute-type :o="$ao" :edit="TRUE" :new="FALSE" :langtag="$tag" :updated="$up->contains($ao->name_lc)"/>
-													@endforeach
-													@break
-
-												@case('+')
-													<div class="ms-auto mt-4 alert alert-warning p-2" style="max-width: 30em; font-size: 0.80em;">
-														It is not possible to create new language tags at the moment. This functionality should come soon.<br>
-														You can create them with an LDIF import though.
-													</div>
-													@break
-
-												@default
-													@foreach ($o->getVisibleAttributes($langtag=sprintf('lang-%s',$tag)) as $ao)
-														<x-attribute-type :o="$ao" :edit="TRUE" :new="FALSE" :langtag="$langtag" :updated="$up->contains($ao->name_lc)"/>
-													@endforeach
-											@endswitch
+									@foreach($o->templates as $template)
+										<div @class(['tab-pane','active'=>$loop->index === 0]) id="template-{{ $template->name }}" role="tabpanel">
+											@include('fragment.template.dn',['template'=>$template,'updated'=>$updated])
 										</div>
 									@endforeach
+
+									<div @class(['tab-pane','active'=>(! $o->templates->count())]) id="template-default" role="tabpanel">
+										<form id="dn-edit" method="POST" class="needs-validation" action="{{ url('entry/update/pending') }}" novalidate readonly>
+											@csrf
+
+											<input type="hidden" name="dn" value="">
+
+											<div class="card-body">
+												<div class="tab-content">
+													@foreach($o->getVisibleAttributes() as $ao)
+														<x-attribute :o="$ao" :edit="false" :editable="true" :new="true" :template="null" :updated="$updated->contains($ao->name_lc)"/>
+													@endforeach
+
+													@include('fragment.dn.add_attr')
+												</div>
+											</div>
+										</form>
+
+										<div class="row d-none pt-3">
+											<div class="col-11 text-end">
+												<x-form.reset form="dn-edit"/>
+												<x-form.submit :action="__('Update')" form="dn-edit"/>
+											</div>
+										</div>
+									</div>
 								</div>
 							</div>
-
-							@include('fragment.dn.add_attr')
-						</form>
-
-						<div class="row d-none pt-3">
-							<div class="col-12 offset-sm-2 col-sm-4 col-lg-2">
-								<x-form.reset form="dn-edit"/>
-								<x-form.submit action="Update" form="dn-edit"/>
-							</div>
 						</div>
 					</div>
 
 					<!-- Internal Attributes -->
 					<div class="tab-pane mt-3" id="internal" role="tabpanel">
-						@foreach ($o->getInternalAttributes() as $ao)
-							<x-attribute-type :o="$ao" :edit="FALSE" :new="FALSE" :langtag="Entry::TAG_NOTAG" :updated="FALSE"/>
+						@foreach($o->getInternalAttributes() as $ao)
+							<x-attribute :o="$ao" :edit="false" :new="false" :template="null" :updated="false"/>
 						@endforeach
 					</div>
 				</div>
@@ -193,18 +160,25 @@
 
 			// Find all input items and turn off readonly
 			$('input.form-control').each(function() {
-				// Except for objectClass - @todo show an "X" instead
 				if ($(this)[0].name.match(/^objectclass/))
 					return;
 
 				$(this).attr('readonly',false);
 			});
 
+			// Find all input items and turn off readonly
+			$('textarea.form-control').each(function() {
+				$(this).attr('readonly',false);
+			});
+
 			// Our password type
-			$('attribute#userPassword .form-select').each(function() {
+			$('attribute#userpassword .form-select').each(function() {
 				$(this).prop('disabled',false);
 			})
 
+			// Objectclasses that can be removed
+			$('.input-group-end i.d-none').removeClass('d-none');
+
 			$('.row.d-none').removeClass('d-none');
 			$('span.addable.d-none').removeClass('d-none');
 			$('span.deletable.d-none').removeClass('d-none');
@@ -229,39 +203,29 @@
 				editmode();
 			});
 
-			$('#newattr').on('change',function(item) {
-				var oc = $('attribute#objectClass input[type=text]')
-					.map((key,item)=>{return $(item).val()}).toArray();
-
-				$.ajax({
-					type: 'POST',
-					beforeSend: function() {},
-					success: function(data) {
-						$('#newattrs').append(data);
-					},
-					error: function(e) {
-						if (e.status !== 412)
-							alert('That didnt work? Please try again....');
-					},
-					url: '{{ url('entry/attr/add') }}/'+item.target.value,
-					data: {
-						objectclasses: oc,
-					},
-					cache: false
-				});
-
-				// Remove the option from the list
-				$(this).find('[value="'+item.target.value+'"]').remove()
-
-				// If there are no more options
-				if ($(this).find("option").length === 1)
-					$('#newattr-select').remove();
-			});
-
 			$('#page-modal').on('shown.bs.modal',function(item) {
 				var that = $(this).find('.modal-content');
 
 				switch ($(item.relatedTarget).attr('id')) {
+					case 'entry-copy-move':
+						$.ajax({
+							method: 'GET',
+							url: '{{ url('modal/copy-move') }}/'+dn,
+							dataType: 'html',
+							cache: false,
+							beforeSend: function() {
+								that.empty().append('<span class="p-3"><i class="fas fa-3x fa-spinner fa-pulse"></i></span>');
+							},
+							success: function(data) {
+								that.empty().html(data);
+							},
+							error: function(e) {
+								if (e.status !== 412)
+									alert('That didnt work? Please try again....');
+							},
+						});
+						break;
+
 					case 'entry-delete':
 						$.ajax({
 							method: 'GET',
@@ -278,7 +242,7 @@
 								if (e.status !== 412)
 									alert('That didnt work? Please try again....');
 							},
-						})
+						});
 						break;
 
 					case 'entry-export':
@@ -318,10 +282,10 @@
 						})
 						break;
 
-					case 'entry-userpassword-check':
+					case 'entry-rename':
 						$.ajax({
 							method: 'GET',
-							url: '{{ url('modal/userpassword-check') }}/'+dn,
+							url: '{{ url('modal/rename') }}/'+dn,
 							dataType: 'html',
 							cache: false,
 							beforeSend: function() {
@@ -334,11 +298,33 @@
 								if (e.status !== 412)
 									alert('That didnt work? Please try again....');
 							},
-						})
+						});
 						break;
 
 					default:
-						console.log('No action for button:'+$(item.relatedTarget).attr('id'));
+						switch ($(item.relatedTarget).attr('name')) {
+							case 'entry-userpassword-check':
+								$.ajax({
+									method: 'GET',
+									url: '{{ url('modal/userpassword-check') }}/'+dn,
+									dataType: 'html',
+									cache: false,
+									beforeSend: function() {
+										that.empty().append('<span class="p-3"><i class="fas fa-3x fa-spinner fa-pulse"></i></span>');
+									},
+									success: function(data) {
+										that.empty().html(data);
+									},
+									error: function(e) {
+										if (e.status !== 412)
+											alert('That didnt work? Please try again....');
+									},
+								})
+								break;
+
+							default:
+								console.log('No action for button:'+$(item.relatedTarget).attr('id'));
+						}
 				}
 			});
 
