@@ -1,12 +1,9 @@
+@use(App\Ldap\Entry)
+
 @extends('home')
 
 @section('page_title')
-	@include('fragment.dn.header',[
-		'langtags'=>($langtags=$o->getLangTags()
-			->flatMap(fn($item)=>$item->values())
-			->unique()
-			->sort())
-	])
+	@include('fragment.dn.header')
 @endsection
 
 @section('page_status')
@@ -27,15 +24,15 @@
 						<table class="table table-bordered table-striped w-100">
 							<thead>
 							<tr>
-								<th>Attribute</th>
-								<th>Tag</th>
-								<th>OLD</th>
-								<th>NEW</th>
+								<th>@lang('Attribute')</th>
+								<th>@lang('Tag')</th>
+								<th>@lang('Old')</th>
+								<th>@lang('New')</th>
 							</tr>
 							</thead>
 
 							<tbody>
-							@foreach ($o->getObjects()->filter(fn($item)=>$item->isDirty()) as $key => $oo)
+							@foreach($o->getObjects()->filter(fn($item)=>$item->isDirty()) as $key => $oo)
 								<tr>
 									<th rowspan="{{ $x=max($oo->values->dot()->keys()->count(),$oo->values_old->dot()->keys()->count())}}">
 										<abbr title="{{ $oo->description }}">{{ $oo->name }}</abbr>
@@ -47,14 +44,19 @@
 										@endif
 
 										<th>
-											{{ $dotkey }}
+											{{ preg_replace('/('.Entry::TAG_NOTAG.')?\.[0-9]+$/','',$dotkey) }}
 										</th>
 
-										@if((! Arr::get($oo->values_old->dot(),$dotkey)) && (! Arr::get($oo->values->dot(),$dotkey)))
+										@if((! $oo->values_old->dot()->get($dotkey)) && (! $oo->values->dot()->get($dotkey)))
 											<td colspan="2" class="text-center">@lang('Ignoring blank value')</td>
 										@else
-											<td>{{ (($r=$oo->render_item_old($dotkey)) !== NULL) ? $r : '['.strtoupper(__('New Value')).']' }}</td>
-											<td>{{ (($r=$oo->render_item_new($dotkey)) !== NULL) ? $r : '['.strtoupper(__('Deleted')).']' }}<input type="hidden" name="{{ $key }}[{{ $oo->no_attr_tags ? \App\Ldap\Entry::TAG_NOTAG : collect(explode('.',$dotkey))->first() }}][]" value="{{ Arr::get($oo->values->dot(),$dotkey) }}"></td>
+											<td>{{ ((($r=$oo->render_item_old($dotkey)) !== NULL) && strlen($r)) ? $r : '['.strtoupper(__('New Value')).']' }}</td>
+											<td>
+												{{ (($r=$oo->render_item_new($dotkey)) !== NULL) ? $r : '['.strtoupper(__('Deleted')).']' }}
+												<input type="hidden"
+													name="{{ $key }}[{{ collect(explode('.',$dotkey))->first() }}][]"
+													value="{{ $r }}">
+											</td>
 										@endif
 									@endforeach
 								</tr>
@@ -69,7 +71,7 @@
 		<div class="row p-3">
 			<div class="col-12 offset-sm-2 col-sm-4 col-lg-2 mx-auto">
 				<x-form.cancel/>
-				<x-form.submit action="Update" form="dn-update"/>
+				<x-form.submit :action="__('Update')" form="dn-update"/>
 			</div>
 		</div>
 
